@@ -11,8 +11,8 @@ from .querier.querier import Querier, QuerierException
 
 
 def load(name):
-    with open(name, 'r') as f:
-        if name.endswith('.json'):
+    with open(name, "r") as f:
+        if name.endswith(".json"):
             data = json.load(f)
         else:
             data = None
@@ -23,20 +23,23 @@ def main():
     argument = Argument()
     arg = argument.parse(sys.argv)
 
-    if os.path.exists(arg.config_file) and arg.config_file.endswith('.json'):
+    if os.path.exists(arg.config_file) and arg.config_file.endswith(".json"):
         config = load(arg.config_file)
     else:
-        Logger.error('config invalid: %s' % arg.config_file)
+        Logger.error("config invalid: %s" % arg.config_file)
         return -1
 
     if len(arg.gerrit_query.strip()) == 0:
-        Logger.error('query invalid: %s' % arg.gerrit_query)
+        Logger.error("query invalid: %s" % arg.gerrit_query)
         return -2
 
-    query = arg.gerrit_query.strip().split(',')
+    query = arg.gerrit_query.strip().split(",")
 
-    if os.path.exists(arg.output_file) or os.path.splitext(arg.output_file)[1] not in Printer.format():
-        Logger.error('output invalid: %s' % arg.output_file)
+    if (
+        os.path.exists(arg.output_file)
+        or os.path.splitext(arg.output_file)[1] not in Printer.format()
+    ):
+        Logger.error("output invalid: %s" % arg.output_file)
         return -3
 
     try:
